Actualiza un servidor SFTP

Para actualizar los usuarios que pueden conectarse a un servidor de Cloud FTP, actualiza la configuración de acceso del servidor. También puedes actualizar metadatos, como el nombre visible del servidor.

No puedes cambiar si un servidor es externo o interno después de que se crea.

Roles obligatorios

Para obtener el permiso que necesitas para actualizar un servidor SFTP, pídele a tu administrador que te otorgue el rol de IAM Administrador de Cloud FTP (roles/ftp.admin) en tu proyecto. Para obtener más información sobre cómo otorgar roles, consulta Administra el acceso a proyectos, carpetas y organizaciones.

Este rol predefinido contiene el ftp.servers.update permiso, que se requiere para actualizar un servidor SFTP.

También puedes obtener este permiso con roles personalizados o otros roles predefinidos.

Actualiza el acceso para un servidor externo

gcloud

Para actualizar la configuración de acceso de un servidor externo, ejecuta el gcloud alpha storage ftp servers update comando. Proporciona la marca --allowed-cidr-blocks.

Antes de usar cualquiera de los datos de comando a continuación, realiza los siguientes reemplazos:

  • SERVER_ID: Es el ID del servidor.
  • LOCATION_ID: Es la ubicación del servidor, como us-west1.
  • CIDR_BLOCK: Es un bloque de CIDR que tiene permiso para acceder al servidor. Por ejemplo, 192.0.2.0/24. Debes proporcionar al menos un valor y puedes proporcionar un máximo de 500 bloques de CIDR en una lista separada por comas. Para permitir conexiones desde todas las direcciones IP, usa 0.0.0.0/0.

Ejecuta el siguiente comando:

Linux, macOS o Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --allowed-cidr-blocks=CIDR_BLOCK
El servidor tarda unos segundos en actualizarse.

REST

Para actualizar la configuración de acceso de un servidor externo, usa el servers.patch método. En el parámetro de consulta updateMask, proporciona el campo externalConfig.

Antes de usar cualquiera de los datos de solicitud a continuación, realiza los siguientes reemplazos:

  • PROJECT_ID: Es el Google Cloud ID del proyecto del servidor.
  • LOCATION_ID: Es la ubicación del servidor, como us-west1.
  • SERVER_ID: Es el ID del servidor.
  • CIDR_BLOCK: Es un bloque de CIDR que tiene permiso para acceder al servidor. Por ejemplo, 192.0.2.0/24. Debes proporcionar al menos un valor y puedes proporcionar un máximo de 500 bloques de CIDR . Para permitir conexiones desde todas las direcciones IP, usa 0.0.0.0/0.

Método HTTP y URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=externalConfig

Cuerpo JSON de la solicitud:

{
  "externalConfig": {
    "allowedCidrBlocks": [
      "CIDR_BLOCK"
    ]
  }
}

Para enviar tu solicitud, expande una de estas opciones:

La respuesta identifica una operación de larga duración. El servidor tarda unos segundos en actualizarse.

Actualiza el acceso para un servidor interno

gcloud

Para actualizar la configuración de acceso de un servidor interno, ejecuta el gcloud alpha storage ftp servers update comando. Proporciona la marca --consumer-accept-list y, de manera opcional, la marca --consumer-reject-list.

Antes de usar cualquiera de los datos de comando a continuación, realiza los siguientes reemplazos:

  • SERVER_ID: Es el ID del servidor.
  • LOCATION_ID: Es la ubicación del servidor, como us-west1.
  • PROJECT_TO_ALLOW: Es el ID del proyecto o el número de un proyecto de consumidor que tiene permiso para conectarse al servidor mediante Private Service Connect. Por ejemplo, example-allowed-project. Debes especificar al menos un proyecto.

    Puedes permitir un máximo de 500 proyectos. Proporciona varios proyectos y sus límites de conexión respectivos en una lista separada por comas. Por ejemplo, --consumer-accept-list=projectA=20,projectB=15.

  • CONNECTION_LIMIT: Es la cantidad máxima de extremos de Private Service Connect que se pueden crear en el proyecto de consumidor. El valor debe ser de 1 a 250 extremos.
  • (Opcional) PROJECT_TO_REJECT: Es el ID del proyecto o el número de un proyecto de consumidor al que se le prohíbe conectarse al servidor. Por ejemplo, example-rejected-project. Se rechaza el acceso al servidor de los proyectos de esta lista, incluso si se incluyen en la lista de proyectos permitidos.

    Puedes rechazar un máximo de 64 proyectos. Proporciona varios proyectos en una lista separada por comas.

    Si no deseas rechazar ningún proyecto de forma explícita, omite la --consumer-reject-list marca.

Ejecuta el siguiente comando:

Linux, macOS o Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT \
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT `
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT ^
    --consumer-reject-list=PROJECT_TO_REJECT
El servidor tarda unos segundos en actualizarse.

REST

Para actualizar la configuración de acceso de un servidor interno, usa el servers.patch método. En el parámetro de consulta updateMask, proporciona el campo internalConfig.

Antes de usar cualquiera de los datos de solicitud a continuación, realiza los siguientes reemplazos:

  • PROJECT_ID: Es el Google Cloud ID del proyecto del servidor.
  • LOCATION_ID: Es la ubicación del servidor, como us-west1.
  • SERVER_ID: Es el ID del servidor.
  • PROJECT_TO_ALLOW: Es el ID del proyecto o el número de un proyecto de consumidor que tiene permiso para conectarse al servidor mediante Private Service Connect. Por ejemplo, example-allowed-project. Debes especificar al menos un proyecto.

    Puedes permitir un máximo de 500 proyectos.

  • CONNECTION_LIMIT: Es la cantidad máxima de extremos de Private Service Connect que se pueden crear en el proyecto de consumidor. El valor debe ser de 1 a 250 extremos.
  • (Opcional) PROJECT_TO_REJECT: Es el ID del proyecto o el número de un proyecto de consumidor al que se le prohíbe conectarse al servidor. Por ejemplo, example-rejected-project. Se rechaza el acceso al servidor de los proyectos de esta lista, incluso si se incluyen en la lista de proyectos permitidos.

    Puedes rechazar un máximo de 64 proyectos.

    Si no deseas rechazar ningún proyecto de forma explícita, omite el consumerRejectList objeto.

Método HTTP y URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=internalConfig

Cuerpo JSON de la solicitud:

{
  "internalConfig": {
    "consumerAcceptList": [
      {
        "project": "projects/PROJECT_TO_ALLOW",
        "connectionLimit": CONNECTION_LIMIT
      }
    ],
    "consumerRejectList": [
      {
        "project": "projects/PROJECT_TO_REJECT"
      }
    ]
  }
}

Para enviar tu solicitud, expande una de estas opciones:

La respuesta identifica una operación de larga duración. El servidor tarda unos segundos en actualizarse.

Actualiza el nombre visible de un servidor

gcloud

Para actualizar metadatos, como el nombre visible de un servidor SFTP, ejecuta el gcloud alpha storage ftp servers update comando.

Antes de usar cualquiera de los datos de comando a continuación, realiza los siguientes reemplazos:

  • SERVER_ID: Es el ID del servidor.
  • LOCATION_ID: Es la ubicación del servidor, como us-west1.
  • DISPLAY_NAME: Es un nombre visible para el servidor.

Ejecuta el siguiente comando:

Linux, macOS o Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --display-name="DISPLAY_NAME"

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --display-name="DISPLAY_NAME"

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --display-name="DISPLAY_NAME"
El servidor tarda unos segundos en actualizarse.

REST

Para actualizar metadatos, como el nombre visible de un servidor SFTP, usa el servers.patch método. En el parámetro de consulta updateMask, proporciona una lista separada por comas de los campos que se actualizarán. En el cuerpo de la solicitud, proporciona un objeto JSON con los valores que se establecerán.

Antes de usar cualquiera de los datos de solicitud a continuación, realiza los siguientes reemplazos:

  • PROJECT_ID: Es el Google Cloud ID del proyecto del servidor.
  • LOCATION_ID: Es la ubicación del servidor, como us-west1.
  • SERVER_ID: Es el ID del servidor.
  • FIELDS_TO_UPDATE: Es una lista separada por comas de los campos que se actualizarán, en relación con el recurso del servidor. Por ejemplo, para actualizar el nombre visible, proporciona el parámetro de consulta updateMask=displayName.
  • DISPLAY_NAME: Es un nombre visible para el servidor.

Método HTTP y URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=FIELDS_TO_UPDATE

Cuerpo JSON de la solicitud:

{
  "displayName": "DISPLAY_NAME"
}

Para enviar tu solicitud, expande una de estas opciones:

La respuesta identifica una operación de larga duración. El servidor tarda unos segundos en actualizarse.